// Pingus - A free Lemmings clone
// Copyright (C) 1999 Ingo Ruhnke <grumbel@gmx.de>

// This program is free software; you can redistribute it and/or
// modify it under the terms of the GNU General Public License
// as published by the Free Software Foundation; either version 2
// of the License, or (at your option) any later version.

// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.

// You should have received a copy of the GNU General Public License
// along with this program; if not, write to the Free Software
// Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.

#include <iostream>
#include <cstdio>
#include <cassert>

#include "pingu.hh"
#include "pingu.hh"
#include "playfield.hh"
#include "plf.hh"
#include "result.hh"

CL_Surface* Playfield::cap;

Playfield::Playfield()
{
  current_pingu = 0;
  x_offset = 0;
  y_offset = 0;
}

Playfield::Playfield(PLF* level_data, Result& result)
{
  world.init(level_data, result);
  current_pingu = 0;
  pingu = world.get_pingu_p();

  x_offset = level_data->get_startx();
  y_offset = level_data->get_starty();

  x_offset.set_range(0, 640 - world.get_width());
  y_offset.set_range(0, 480 - world.get_height());
}

Playfield::~Playfield()
{
}

void
Playfield::draw()
{
  // draw the world (Playfield, pingus, ...)
  world.draw_offset(x_offset, y_offset);

  // draw the capture rectange
  for (int i=0; i < pingu->size(); ++i) {
    if ((*pingu)[i]->is_over(CL_Mouse::get_x()-+x_offset, CL_Mouse::get_y()-y_offset)) {
      cap->put_screen((*pingu)[i]->get_x()-17+x_offset, (*pingu)[i]->get_y()-33+y_offset);
      current_pingu = i;
      break;
    } else {
      current_pingu = -1;
    }
  }
}

void
Playfield::let_move()
{
  // Scroll around if the mouse button is pressed
  if (CL_Mouse::middle_pressed()) {
    if (!mouse_scrolling) {
      mouse_scrolling = true;
      scroll_center_x = CL_Mouse::get_x();
      scroll_center_y = CL_Mouse::get_y();
    }
    x_offset += (scroll_center_x - CL_Mouse::get_x()) / 5;
    y_offset -= (scroll_center_y - CL_Mouse::get_y()) / 5;
  } else {
    mouse_scrolling = false;
  }


  // Let the playfield scroll around
  if (CL_Keyboard::get_keycode(CL_Keyboard::KEY_LEFT) == true) {
    x_offset += 10;
  } else if (CL_Keyboard::get_keycode(CL_Keyboard::KEY_RIGHT) == true) {
    x_offset -= 10;
  } else if (CL_Keyboard::get_keycode(CL_Keyboard::KEY_UP) == true) {
    y_offset += 10;
  } else if (CL_Keyboard::get_keycode(CL_Keyboard::KEY_DOWN) == true) {
    y_offset -= 10;
  }
  
  world.let_move();

  if (current_pingu != -1 && CL_Mouse::left_pressed()) {
    (*pingu)[current_pingu]->set_action(buttons->get_action());
  }
}

void
Playfield::load_data(CL_ResourceManager* resource)
{
  assert(cap = CL_Res_Surface::load("Game/cap", *resource));
}

void
Playfield::set_buttons(ButtonPanel* b)
{
  buttons = b;
}

void
Playfield::write_results()
{
  world.write_results();
}

/* EOF */

