// Pingus - A free Lemmings clone
// Copyright (C) 1999 Ingo Ruhnke <grumbel@gmx.de>

// This program is free software; you can redistribute it and/or
// modify it under the terms of the GNU General Public License
// as published by the Free Software Foundation; either version 2
// of the License, or (at your option) any later version.

// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.

// You should have received a copy of the GNU General Public License
// along with this program; if not, write to the Free Software
// Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.

#ifndef PLF_HH
#define PLF_HH

#include <string>
#include <vector>

#include "plf_datatypes.hh"

// PLF stands for PinguLevelFile it gives a easy methode to read the
// informations from *.plf file, it could also provide a transparent
// access to both binary-compressed and text versions of a plf file.

class PLF
{
private:
  char*    filename;
  char*    fg;
  char*    bg;
  char*    col;
  MapType  maptype;
  int      x_pos;
  int      y_pos;
  int      pingus;
  vector<hotspot_t> hotspot_fg;
  vector<hotspot_t> hotspot_bg;

  vector<exit_data>         exit_v;
  vector<entrance_data> entrance_v;

  vector<trap_data>      traps;
  vector<button_data>  buttons;
public:  
  PLF();
  PLF(const string&);

  plf_token get_token(char*);
  const char* get_bg();
  const char* get_fg();
  const char* get_pngfile();
  const char* get_mapfile();
  int  get_startx();
  int  get_starty();
  int  get_pingus();
  vector<hotspot_t>      get_hotspot_bg();
  vector<hotspot_t>      get_hotspot_fg();
  vector<entrance_data>  get_entrance();
  vector<exit_data>      get_exit();
  vector<trap_data>      get_traps();
  vector<button_data>    get_buttons();
  MapType map_type();
};

#endif

/* EOF */
